export type Maybe<T> = T | null;
export type Exact<T extends { [key: string]: any }> = { [K in keyof T]: T[K] };
/** All built-in and custom scalars, mapped to their actual values */
export type Scalars = {
  ID: string;
  String: string;
  Boolean: boolean;
  Int: number;
  Float: number;
  JSONObject: any;
  Timestamp: any;
};

export type ByronBlockVersionData = {
  __typename?: 'ByronBlockVersionData';
  scriptVersion: Scalars['Int'];
  slotDuration: Scalars['Int'];
  maxBlockSize: Scalars['Int'];
  maxHeaderSize: Scalars['Int'];
  maxTxSize: Scalars['Int'];
  maxProposalSize: Scalars['Int'];
  mpcThd: Scalars['String'];
  heavyDelThd: Scalars['String'];
  updateVoteThd: Scalars['String'];
  updateProposalThd: Scalars['String'];
  updateImplicit: Scalars['String'];
  softforkRule: ByronSoftForkRule;
  txFeePolicy: ByronTxFeePolicy;
  unlockStakeEpoch: Scalars['String'];
};

export type ByronGenesis = {
  __typename?: 'ByronGenesis';
  bootStakeholders: Scalars['JSONObject'];
  heavyDelegation: Scalars['JSONObject'];
  startTime: Scalars['Timestamp'];
  nonAvvmBalances: Scalars['JSONObject'];
  blockVersionData: ByronBlockVersionData;
  protocolConsts: ByronProtocolConsts;
  avvmDistr: Scalars['JSONObject'];
};

export type ByronProtocolConsts = {
  __typename?: 'ByronProtocolConsts';
  k: Scalars['Int'];
  protocolMagic?: Maybe<Scalars['Int']>;
};

export type ByronSoftForkRule = {
  __typename?: 'ByronSoftForkRule';
  initThd: Scalars['String'];
  minThd: Scalars['String'];
  thdDecrement: Scalars['String'];
};

export type ByronTxFeePolicy = {
  __typename?: 'ByronTxFeePolicy';
  summand: Scalars['String'];
  multiplier: Scalars['String'];
};

export type ExtraEntropy = {
  __typename?: 'ExtraEntropy';
  tag: Scalars['String'];
};

export type Genesis = {
  __typename?: 'Genesis';
  byron?: Maybe<ByronGenesis>;
  shelley?: Maybe<ShelleyGenesis>;
};


export type ProtocolVersion = {
  __typename?: 'ProtocolVersion';
  major: Scalars['Int'];
  minor: Scalars['Int'];
};

export type Query = {
  __typename?: 'Query';
  genesis: Genesis;
};

export type ShelleyGenesis = {
  __typename?: 'ShelleyGenesis';
  activeSlotsCoeff: Scalars['Float'];
  epochLength: Scalars['Int'];
  genDelegs?: Maybe<Scalars['JSONObject']>;
  initialFunds: Scalars['JSONObject'];
  maxKESEvolutions: Scalars['Int'];
  maxLovelaceSupply: Scalars['String'];
  networkId: Scalars['String'];
  networkMagic: Scalars['Int'];
  protocolParams: ShelleyProtocolParams;
  securityParam: Scalars['Int'];
  slotLength: Scalars['Int'];
  slotsPerKESPeriod: Scalars['Int'];
  staking?: Maybe<Staking>;
  systemStart: Scalars['String'];
  updateQuorum: Scalars['Int'];
};

export type ShelleyProtocolParams = {
  __typename?: 'ShelleyProtocolParams';
  a0: Scalars['Float'];
  decentralisationParam: Scalars['Int'];
  eMax: Scalars['Int'];
  extraEntropy: ExtraEntropy;
  keyDeposit: Scalars['Int'];
  maxBlockBodySize: Scalars['Int'];
  maxBlockHeaderSize: Scalars['Int'];
  maxTxSize: Scalars['Int'];
  minFeeA: Scalars['Int'];
  minFeeB: Scalars['Int'];
  minPoolCost: Scalars['Int'];
  minUTxOValue: Scalars['Int'];
  nOpt: Scalars['Int'];
  poolDeposit: Scalars['Int'];
  protocolVersion: ProtocolVersion;
  rho: Scalars['Float'];
  tau: Scalars['Float'];
};

export type Staking = {
  __typename?: 'Staking';
  pools: Scalars['JSONObject'];
  stake: Scalars['JSONObject'];
};

